/* Generated by ./src/xlat/gen.sh from ./src/xlat/uring_iowq_acct.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(IO_WQ_BOUND) || (defined(HAVE_DECL_IO_WQ_BOUND) && HAVE_DECL_IO_WQ_BOUND)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IO_WQ_BOUND) == (0), "IO_WQ_BOUND != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IO_WQ_BOUND 0
#endif
#if defined(IO_WQ_UNBOUND) || (defined(HAVE_DECL_IO_WQ_UNBOUND) && HAVE_DECL_IO_WQ_UNBOUND)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IO_WQ_UNBOUND) == (1), "IO_WQ_UNBOUND != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IO_WQ_UNBOUND 1
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat uring_iowq_acct in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data uring_iowq_acct_xdata[] = {
 [IO_WQ_BOUND] = XLAT(IO_WQ_BOUND),
 #define XLAT_VAL_0 ((unsigned) (IO_WQ_BOUND))
 #define XLAT_STR_0 STRINGIFY(IO_WQ_BOUND)
 [IO_WQ_UNBOUND] = XLAT(IO_WQ_UNBOUND),
 #define XLAT_VAL_1 ((unsigned) (IO_WQ_UNBOUND))
 #define XLAT_STR_1 STRINGIFY(IO_WQ_UNBOUND)
};
static
const struct xlat uring_iowq_acct[1] = { {
 .data = uring_iowq_acct_xdata,
 .size = ARRAY_SIZE(uring_iowq_acct_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
