/* Generated by ./src/xlat/gen.sh from ./src/xlat/bpf_file_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(BPF_F_RDONLY) || (defined(HAVE_DECL_BPF_F_RDONLY) && HAVE_DECL_BPF_F_RDONLY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_RDONLY) == ((1U << 3)), "BPF_F_RDONLY != (1U << 3)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_RDONLY (1U << 3)
#endif
#if defined(BPF_F_WRONLY) || (defined(HAVE_DECL_BPF_F_WRONLY) && HAVE_DECL_BPF_F_WRONLY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_WRONLY) == ((1U << 4)), "BPF_F_WRONLY != (1U << 4)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_WRONLY (1U << 4)
#endif
#if defined(BPF_F_PATH_FD) || (defined(HAVE_DECL_BPF_F_PATH_FD) && HAVE_DECL_BPF_F_PATH_FD)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_F_PATH_FD) == ((1U << 14)), "BPF_F_PATH_FD != (1U << 14)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_F_PATH_FD (1U << 14)
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat bpf_file_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data bpf_file_flags_xdata[] = {
 XLAT(BPF_F_RDONLY),
 #define XLAT_VAL_0 ((unsigned) (BPF_F_RDONLY))
 #define XLAT_STR_0 STRINGIFY(BPF_F_RDONLY)
 XLAT(BPF_F_WRONLY),
 #define XLAT_VAL_1 ((unsigned) (BPF_F_WRONLY))
 #define XLAT_STR_1 STRINGIFY(BPF_F_WRONLY)
 XLAT(BPF_F_PATH_FD),
 #define XLAT_VAL_2 ((unsigned) (BPF_F_PATH_FD))
 #define XLAT_STR_2 STRINGIFY(BPF_F_PATH_FD)
};
static
const struct xlat bpf_file_flags[1] = { {
 .data = bpf_file_flags_xdata,
 .size = ARRAY_SIZE(bpf_file_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
