/* Generated by ./src/xlat/gen.sh from ./src/xlat/nl_netfilter_subsys_ids.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat nl_netfilter_subsys_ids in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data nl_netfilter_subsys_ids_xdata[] = {
 [NFNL_SUBSYS_NONE] = XLAT(NFNL_SUBSYS_NONE),
 #define XLAT_VAL_0 ((unsigned) (NFNL_SUBSYS_NONE))
 #define XLAT_STR_0 STRINGIFY(NFNL_SUBSYS_NONE)
 [NFNL_SUBSYS_CTNETLINK] = XLAT(NFNL_SUBSYS_CTNETLINK),
 #define XLAT_VAL_1 ((unsigned) (NFNL_SUBSYS_CTNETLINK))
 #define XLAT_STR_1 STRINGIFY(NFNL_SUBSYS_CTNETLINK)
 [NFNL_SUBSYS_CTNETLINK_EXP] = XLAT(NFNL_SUBSYS_CTNETLINK_EXP),
 #define XLAT_VAL_2 ((unsigned) (NFNL_SUBSYS_CTNETLINK_EXP))
 #define XLAT_STR_2 STRINGIFY(NFNL_SUBSYS_CTNETLINK_EXP)
 [NFNL_SUBSYS_QUEUE] = XLAT(NFNL_SUBSYS_QUEUE),
 #define XLAT_VAL_3 ((unsigned) (NFNL_SUBSYS_QUEUE))
 #define XLAT_STR_3 STRINGIFY(NFNL_SUBSYS_QUEUE)
 [NFNL_SUBSYS_ULOG] = XLAT(NFNL_SUBSYS_ULOG),
 #define XLAT_VAL_4 ((unsigned) (NFNL_SUBSYS_ULOG))
 #define XLAT_STR_4 STRINGIFY(NFNL_SUBSYS_ULOG)
 [NFNL_SUBSYS_OSF] = XLAT(NFNL_SUBSYS_OSF),
 #define XLAT_VAL_5 ((unsigned) (NFNL_SUBSYS_OSF))
 #define XLAT_STR_5 STRINGIFY(NFNL_SUBSYS_OSF)
 [NFNL_SUBSYS_IPSET] = XLAT(NFNL_SUBSYS_IPSET),
 #define XLAT_VAL_6 ((unsigned) (NFNL_SUBSYS_IPSET))
 #define XLAT_STR_6 STRINGIFY(NFNL_SUBSYS_IPSET)
 [NFNL_SUBSYS_ACCT] = XLAT(NFNL_SUBSYS_ACCT),
 #define XLAT_VAL_7 ((unsigned) (NFNL_SUBSYS_ACCT))
 #define XLAT_STR_7 STRINGIFY(NFNL_SUBSYS_ACCT)
 [NFNL_SUBSYS_CTNETLINK_TIMEOUT] = XLAT(NFNL_SUBSYS_CTNETLINK_TIMEOUT),
 #define XLAT_VAL_8 ((unsigned) (NFNL_SUBSYS_CTNETLINK_TIMEOUT))
 #define XLAT_STR_8 STRINGIFY(NFNL_SUBSYS_CTNETLINK_TIMEOUT)
 [NFNL_SUBSYS_CTHELPER] = XLAT(NFNL_SUBSYS_CTHELPER),
 #define XLAT_VAL_9 ((unsigned) (NFNL_SUBSYS_CTHELPER))
 #define XLAT_STR_9 STRINGIFY(NFNL_SUBSYS_CTHELPER)
 [NFNL_SUBSYS_NFTABLES] = XLAT(NFNL_SUBSYS_NFTABLES),
 #define XLAT_VAL_10 ((unsigned) (NFNL_SUBSYS_NFTABLES))
 #define XLAT_STR_10 STRINGIFY(NFNL_SUBSYS_NFTABLES)
 [NFNL_SUBSYS_NFT_COMPAT] = XLAT(NFNL_SUBSYS_NFT_COMPAT),
 #define XLAT_VAL_11 ((unsigned) (NFNL_SUBSYS_NFT_COMPAT))
 #define XLAT_STR_11 STRINGIFY(NFNL_SUBSYS_NFT_COMPAT)
 [NFNL_SUBSYS_HOOK] = XLAT(NFNL_SUBSYS_HOOK),
 #define XLAT_VAL_12 ((unsigned) (NFNL_SUBSYS_HOOK))
 #define XLAT_STR_12 STRINGIFY(NFNL_SUBSYS_HOOK)
};
static
const struct xlat nl_netfilter_subsys_ids[1] = { {
 .data = nl_netfilter_subsys_ids_xdata,
 .size = ARRAY_SIZE(nl_netfilter_subsys_ids_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
