/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_netconf_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_netconf_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_netconf_attrs_xdata[] = {
 [NETCONFA_UNSPEC] = XLAT(NETCONFA_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (NETCONFA_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(NETCONFA_UNSPEC)
 [NETCONFA_IFINDEX] = XLAT(NETCONFA_IFINDEX),
 #define XLAT_VAL_1 ((unsigned) (NETCONFA_IFINDEX))
 #define XLAT_STR_1 STRINGIFY(NETCONFA_IFINDEX)
 [NETCONFA_FORWARDING] = XLAT(NETCONFA_FORWARDING),
 #define XLAT_VAL_2 ((unsigned) (NETCONFA_FORWARDING))
 #define XLAT_STR_2 STRINGIFY(NETCONFA_FORWARDING)
 [NETCONFA_RP_FILTER] = XLAT(NETCONFA_RP_FILTER),
 #define XLAT_VAL_3 ((unsigned) (NETCONFA_RP_FILTER))
 #define XLAT_STR_3 STRINGIFY(NETCONFA_RP_FILTER)
 [NETCONFA_MC_FORWARDING] = XLAT(NETCONFA_MC_FORWARDING),
 #define XLAT_VAL_4 ((unsigned) (NETCONFA_MC_FORWARDING))
 #define XLAT_STR_4 STRINGIFY(NETCONFA_MC_FORWARDING)
 [NETCONFA_PROXY_NEIGH] = XLAT(NETCONFA_PROXY_NEIGH),
 #define XLAT_VAL_5 ((unsigned) (NETCONFA_PROXY_NEIGH))
 #define XLAT_STR_5 STRINGIFY(NETCONFA_PROXY_NEIGH)
 [NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN] = XLAT(NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN),
 #define XLAT_VAL_6 ((unsigned) (NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN))
 #define XLAT_STR_6 STRINGIFY(NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN)
 [NETCONFA_INPUT] = XLAT(NETCONFA_INPUT),
 #define XLAT_VAL_7 ((unsigned) (NETCONFA_INPUT))
 #define XLAT_STR_7 STRINGIFY(NETCONFA_INPUT)
 [NETCONFA_BC_FORWARDING] = XLAT(NETCONFA_BC_FORWARDING),
 #define XLAT_VAL_8 ((unsigned) (NETCONFA_BC_FORWARDING))
 #define XLAT_STR_8 STRINGIFY(NETCONFA_BC_FORWARDING)
};
static
const struct xlat rtnl_netconf_attrs[1] = { {
 .data = rtnl_netconf_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_netconf_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
