/* Generated by ./src/xlat/gen.sh from ./src/xlat/mtd_type_options.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat mtd_type_options[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data mtd_type_options_xdata[] = {
 [MTD_ABSENT] = XLAT(MTD_ABSENT),
 #define XLAT_VAL_0 ((unsigned) (MTD_ABSENT))
 #define XLAT_STR_0 STRINGIFY(MTD_ABSENT)
 [MTD_RAM] = XLAT(MTD_RAM),
 #define XLAT_VAL_1 ((unsigned) (MTD_RAM))
 #define XLAT_STR_1 STRINGIFY(MTD_RAM)
 [MTD_ROM] = XLAT(MTD_ROM),
 #define XLAT_VAL_2 ((unsigned) (MTD_ROM))
 #define XLAT_STR_2 STRINGIFY(MTD_ROM)
 [MTD_NORFLASH] = XLAT(MTD_NORFLASH),
 #define XLAT_VAL_3 ((unsigned) (MTD_NORFLASH))
 #define XLAT_STR_3 STRINGIFY(MTD_NORFLASH)
 [MTD_NANDFLASH] = XLAT(MTD_NANDFLASH),
 #define XLAT_VAL_4 ((unsigned) (MTD_NANDFLASH))
 #define XLAT_STR_4 STRINGIFY(MTD_NANDFLASH)
 [MTD_DATAFLASH] = XLAT(MTD_DATAFLASH),
 #define XLAT_VAL_5 ((unsigned) (MTD_DATAFLASH))
 #define XLAT_STR_5 STRINGIFY(MTD_DATAFLASH)
 [MTD_UBIVOLUME] = XLAT(MTD_UBIVOLUME),
 #define XLAT_VAL_6 ((unsigned) (MTD_UBIVOLUME))
 #define XLAT_STR_6 STRINGIFY(MTD_UBIVOLUME)
 [MTD_MLCNANDFLASH] = XLAT(MTD_MLCNANDFLASH),
 #define XLAT_VAL_7 ((unsigned) (MTD_MLCNANDFLASH))
 #define XLAT_STR_7 STRINGIFY(MTD_MLCNANDFLASH)
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat mtd_type_options[1] = { {
 .data = mtd_type_options_xdata,
 .size = ARRAY_SIZE(mtd_type_options_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
