/* Generated by ./src/xlat/gen.sh from ./src/xlat/btrfs_scrub_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat btrfs_scrub_flags[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data btrfs_scrub_flags_xdata[] = {
 XLAT_TYPE(uint64_t, BTRFS_SCRUB_READONLY),
 #define XLAT_VAL_0 ((uint64_t) (BTRFS_SCRUB_READONLY))
 #define XLAT_STR_0 STRINGIFY(BTRFS_SCRUB_READONLY)
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat btrfs_scrub_flags[1] = { {
 .data = btrfs_scrub_flags_xdata,
 .size = ARRAY_SIZE(btrfs_scrub_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
