/* Generated by ./src/xlat/gen.sh from ./src/xlat/bpf_miscop.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(BPF_TAX) || (defined(HAVE_DECL_BPF_TAX) && HAVE_DECL_BPF_TAX)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_TAX) == (0x00), "BPF_TAX != 0x00");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_TAX 0x00
#endif
#if defined(BPF_TXA) || (defined(HAVE_DECL_BPF_TXA) && HAVE_DECL_BPF_TXA)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((BPF_TXA) == (0x80), "BPF_TXA != 0x80");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define BPF_TXA 0x80
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat bpf_miscop in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data bpf_miscop_xdata[] = {
 XLAT(BPF_TAX),
 #define XLAT_VAL_0 ((unsigned) (BPF_TAX))
 #define XLAT_STR_0 STRINGIFY(BPF_TAX)
 XLAT(BPF_TXA),
 #define XLAT_VAL_1 ((unsigned) (BPF_TXA))
 #define XLAT_STR_1 STRINGIFY(BPF_TXA)
};
static
const struct xlat bpf_miscop[1] = { {
 .data = bpf_miscop_xdata,
 .size = ARRAY_SIZE(bpf_miscop_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
