/* Generated by ./src/xlat/gen.sh from ./src/xlat/multicast_router_types.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat multicast_router_types in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data multicast_router_types_xdata[] = {
 [MDB_RTR_TYPE_DISABLED] = XLAT(MDB_RTR_TYPE_DISABLED),
 #define XLAT_VAL_0 ((unsigned) (MDB_RTR_TYPE_DISABLED))
 #define XLAT_STR_0 STRINGIFY(MDB_RTR_TYPE_DISABLED)
 [MDB_RTR_TYPE_TEMP_QUERY] = XLAT(MDB_RTR_TYPE_TEMP_QUERY),
 #define XLAT_VAL_1 ((unsigned) (MDB_RTR_TYPE_TEMP_QUERY))
 #define XLAT_STR_1 STRINGIFY(MDB_RTR_TYPE_TEMP_QUERY)
 [MDB_RTR_TYPE_PERM] = XLAT(MDB_RTR_TYPE_PERM),
 #define XLAT_VAL_2 ((unsigned) (MDB_RTR_TYPE_PERM))
 #define XLAT_STR_2 STRINGIFY(MDB_RTR_TYPE_PERM)
 [MDB_RTR_TYPE_TEMP] = XLAT(MDB_RTR_TYPE_TEMP),
 #define XLAT_VAL_3 ((unsigned) (MDB_RTR_TYPE_TEMP))
 #define XLAT_STR_3 STRINGIFY(MDB_RTR_TYPE_TEMP)
};
static
const struct xlat multicast_router_types[1] = { {
 .data = multicast_router_types_xdata,
 .size = ARRAY_SIZE(multicast_router_types_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
