/* Generated by ./src/xlat/gen.sh from ./src/xlat/btrfs_qgroup_limit_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat btrfs_qgroup_limit_flags[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data btrfs_qgroup_limit_flags_xdata[] = {
 XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_MAX_RFER),
 #define XLAT_VAL_0 ((uint64_t) (BTRFS_QGROUP_LIMIT_MAX_RFER))
 #define XLAT_STR_0 STRINGIFY(BTRFS_QGROUP_LIMIT_MAX_RFER)
 XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_MAX_EXCL),
 #define XLAT_VAL_1 ((uint64_t) (BTRFS_QGROUP_LIMIT_MAX_EXCL))
 #define XLAT_STR_1 STRINGIFY(BTRFS_QGROUP_LIMIT_MAX_EXCL)
 XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_RSV_RFER),
 #define XLAT_VAL_2 ((uint64_t) (BTRFS_QGROUP_LIMIT_RSV_RFER))
 #define XLAT_STR_2 STRINGIFY(BTRFS_QGROUP_LIMIT_RSV_RFER)
 XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_RSV_EXCL),
 #define XLAT_VAL_3 ((uint64_t) (BTRFS_QGROUP_LIMIT_RSV_EXCL))
 #define XLAT_STR_3 STRINGIFY(BTRFS_QGROUP_LIMIT_RSV_EXCL)
 XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_RFER_CMPR),
 #define XLAT_VAL_4 ((uint64_t) (BTRFS_QGROUP_LIMIT_RFER_CMPR))
 #define XLAT_STR_4 STRINGIFY(BTRFS_QGROUP_LIMIT_RFER_CMPR)
 XLAT_TYPE(uint64_t, BTRFS_QGROUP_LIMIT_EXCL_CMPR),
 #define XLAT_VAL_5 ((uint64_t) (BTRFS_QGROUP_LIMIT_EXCL_CMPR))
 #define XLAT_STR_5 STRINGIFY(BTRFS_QGROUP_LIMIT_EXCL_CMPR)
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat btrfs_qgroup_limit_flags[1] = { {
 .data = btrfs_qgroup_limit_flags_xdata,
 .size = ARRAY_SIZE(btrfs_qgroup_limit_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
