/* Generated by ./src/xlat/gen.sh from ./src/xlat/term_cmds_overlapping.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat term_cmds_overlapping in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data term_cmds_overlapping_xdata[] = {

#if defined(TCGETS) || (defined(HAVE_DECL_TCGETS) && HAVE_DECL_TCGETS)
  XLAT(TCGETS),
 #define XLAT_VAL_0 ((unsigned) (TCGETS))
 #define XLAT_STR_0 STRINGIFY(TCGETS)
#endif
#if defined(TCSETS) || (defined(HAVE_DECL_TCSETS) && HAVE_DECL_TCSETS)
  XLAT(TCSETS),
 #define XLAT_VAL_1 ((unsigned) (TCSETS))
 #define XLAT_STR_1 STRINGIFY(TCSETS)
#endif
#if defined(TCSETSW) || (defined(HAVE_DECL_TCSETSW) && HAVE_DECL_TCSETSW)
  XLAT(TCSETSW),
 #define XLAT_VAL_2 ((unsigned) (TCSETSW))
 #define XLAT_STR_2 STRINGIFY(TCSETSW)
#endif
#if defined(TCSETSF) || (defined(HAVE_DECL_TCSETSF) && HAVE_DECL_TCSETSF)
  XLAT(TCSETSF),
 #define XLAT_VAL_3 ((unsigned) (TCSETSF))
 #define XLAT_STR_3 STRINGIFY(TCSETSF)
#endif
#if defined(TCGETA) || (defined(HAVE_DECL_TCGETA) && HAVE_DECL_TCGETA)
  XLAT(TCGETA),
 #define XLAT_VAL_4 ((unsigned) (TCGETA))
 #define XLAT_STR_4 STRINGIFY(TCGETA)
#endif
#if defined(TCSETA) || (defined(HAVE_DECL_TCSETA) && HAVE_DECL_TCSETA)
  XLAT(TCSETA),
 #define XLAT_VAL_5 ((unsigned) (TCSETA))
 #define XLAT_STR_5 STRINGIFY(TCSETA)
#endif
#if defined(TCSETAW) || (defined(HAVE_DECL_TCSETAW) && HAVE_DECL_TCSETAW)
  XLAT(TCSETAW),
 #define XLAT_VAL_6 ((unsigned) (TCSETAW))
 #define XLAT_STR_6 STRINGIFY(TCSETAW)
#endif
#if defined(TCSETAF) || (defined(HAVE_DECL_TCSETAF) && HAVE_DECL_TCSETAF)
  XLAT(TCSETAF),
 #define XLAT_VAL_7 ((unsigned) (TCSETAF))
 #define XLAT_STR_7 STRINGIFY(TCSETAF)
#endif
};
static
const struct xlat term_cmds_overlapping[1] = { {
 .data = term_cmds_overlapping_xdata,
 .size = ARRAY_SIZE(term_cmds_overlapping_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
