/* Generated by ./src/xlat/gen.sh from ./src/xlat/shadow_stack_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(SHADOW_STACK_SET_TOKEN) || (defined(HAVE_DECL_SHADOW_STACK_SET_TOKEN) && HAVE_DECL_SHADOW_STACK_SET_TOKEN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SHADOW_STACK_SET_TOKEN) == (1), "SHADOW_STACK_SET_TOKEN != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SHADOW_STACK_SET_TOKEN 1
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat shadow_stack_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data shadow_stack_flags_xdata[] = {
 XLAT(SHADOW_STACK_SET_TOKEN),
 #define XLAT_VAL_0 ((unsigned) (SHADOW_STACK_SET_TOKEN))
 #define XLAT_STR_0 STRINGIFY(SHADOW_STACK_SET_TOKEN)
};
static
const struct xlat shadow_stack_flags[1] = { {
 .data = shadow_stack_flags_xdata,
 .size = ARRAY_SIZE(shadow_stack_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
