/*
 * Copyright (c) 2017-2018 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

static const char lockdir[] = "attach-p-cmd.test-lock";
static const char pidfile[] = "attach-p-cmd.test-pid";
