/*
 * Copyright (c) 2023 Dmitry V. Levin <ldv@strace.io>
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef STRACE_EXITKILL_H
# define STRACE_EXITKILL_H

extern bool is_exitkill_supported(void);

#endif /* !STRACE_EXITKILL_H */
