/* Generated by ./src/xlat/gen.sh from ./src/xlat/if_dqinfo_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(DQF_ROOT_SQUASH) || (defined(HAVE_DECL_DQF_ROOT_SQUASH) && HAVE_DECL_DQF_ROOT_SQUASH)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((DQF_ROOT_SQUASH) == ((1 << 0)), "DQF_ROOT_SQUASH != (1 << 0)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define DQF_ROOT_SQUASH (1 << 0)
#endif
#if defined(DQF_SYS_FILE) || (defined(HAVE_DECL_DQF_SYS_FILE) && HAVE_DECL_DQF_SYS_FILE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((DQF_SYS_FILE) == ((1 << 16)), "DQF_SYS_FILE != (1 << 16)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define DQF_SYS_FILE (1 << 16)
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat if_dqinfo_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data if_dqinfo_flags_xdata[] = {
 XLAT(DQF_ROOT_SQUASH),
 #define XLAT_VAL_0 ((unsigned) (DQF_ROOT_SQUASH))
 #define XLAT_STR_0 STRINGIFY(DQF_ROOT_SQUASH)
 XLAT(DQF_SYS_FILE),
 #define XLAT_VAL_1 ((unsigned) (DQF_SYS_FILE))
 #define XLAT_STR_1 STRINGIFY(DQF_SYS_FILE)
};
static
const struct xlat if_dqinfo_flags[1] = { {
 .data = if_dqinfo_flags_xdata,
 .size = ARRAY_SIZE(if_dqinfo_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
