/* Generated by ./src/xlat/gen.sh from ./src/xlat/tls_info_configs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((TLS_CONF_BASE) == (1), "TLS_CONF_BASE != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((TLS_CONF_SW) == (2), "TLS_CONF_SW != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((TLS_CONF_HW) == (3), "TLS_CONF_HW != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((TLS_CONF_HW_RECORD) == (4), "TLS_CONF_HW_RECORD != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat tls_info_configs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data tls_info_configs_xdata[] = {
 [TLS_CONF_BASE] = XLAT(TLS_CONF_BASE),
 #define XLAT_VAL_0 ((unsigned) (TLS_CONF_BASE))
 #define XLAT_STR_0 STRINGIFY(TLS_CONF_BASE)
 [TLS_CONF_SW] = XLAT(TLS_CONF_SW),
 #define XLAT_VAL_1 ((unsigned) (TLS_CONF_SW))
 #define XLAT_STR_1 STRINGIFY(TLS_CONF_SW)
 [TLS_CONF_HW] = XLAT(TLS_CONF_HW),
 #define XLAT_VAL_2 ((unsigned) (TLS_CONF_HW))
 #define XLAT_STR_2 STRINGIFY(TLS_CONF_HW)
 [TLS_CONF_HW_RECORD] = XLAT(TLS_CONF_HW_RECORD),
 #define XLAT_VAL_3 ((unsigned) (TLS_CONF_HW_RECORD))
 #define XLAT_STR_3 STRINGIFY(TLS_CONF_HW_RECORD)
};
static
const struct xlat tls_info_configs[1] = { {
 .data = tls_info_configs_xdata,
 .size = ARRAY_SIZE(tls_info_configs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
