/* Generated by ./src/xlat/gen.sh from ./src/xlat/v4l2_fields.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat v4l2_fields[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data v4l2_fields_xdata[] = {
 [V4L2_FIELD_ANY] = XLAT(V4L2_FIELD_ANY),
 #define XLAT_VAL_0 ((unsigned) (V4L2_FIELD_ANY))
 #define XLAT_STR_0 STRINGIFY(V4L2_FIELD_ANY)
 [V4L2_FIELD_NONE] = XLAT(V4L2_FIELD_NONE),
 #define XLAT_VAL_1 ((unsigned) (V4L2_FIELD_NONE))
 #define XLAT_STR_1 STRINGIFY(V4L2_FIELD_NONE)
 [V4L2_FIELD_TOP] = XLAT(V4L2_FIELD_TOP),
 #define XLAT_VAL_2 ((unsigned) (V4L2_FIELD_TOP))
 #define XLAT_STR_2 STRINGIFY(V4L2_FIELD_TOP)
 [V4L2_FIELD_BOTTOM] = XLAT(V4L2_FIELD_BOTTOM),
 #define XLAT_VAL_3 ((unsigned) (V4L2_FIELD_BOTTOM))
 #define XLAT_STR_3 STRINGIFY(V4L2_FIELD_BOTTOM)
 [V4L2_FIELD_INTERLACED] = XLAT(V4L2_FIELD_INTERLACED),
 #define XLAT_VAL_4 ((unsigned) (V4L2_FIELD_INTERLACED))
 #define XLAT_STR_4 STRINGIFY(V4L2_FIELD_INTERLACED)
 [V4L2_FIELD_SEQ_TB] = XLAT(V4L2_FIELD_SEQ_TB),
 #define XLAT_VAL_5 ((unsigned) (V4L2_FIELD_SEQ_TB))
 #define XLAT_STR_5 STRINGIFY(V4L2_FIELD_SEQ_TB)
 [V4L2_FIELD_SEQ_BT] = XLAT(V4L2_FIELD_SEQ_BT),
 #define XLAT_VAL_6 ((unsigned) (V4L2_FIELD_SEQ_BT))
 #define XLAT_STR_6 STRINGIFY(V4L2_FIELD_SEQ_BT)
 [V4L2_FIELD_ALTERNATE] = XLAT(V4L2_FIELD_ALTERNATE),
 #define XLAT_VAL_7 ((unsigned) (V4L2_FIELD_ALTERNATE))
 #define XLAT_STR_7 STRINGIFY(V4L2_FIELD_ALTERNATE)
 [V4L2_FIELD_INTERLACED_TB] = XLAT(V4L2_FIELD_INTERLACED_TB),
 #define XLAT_VAL_8 ((unsigned) (V4L2_FIELD_INTERLACED_TB))
 #define XLAT_STR_8 STRINGIFY(V4L2_FIELD_INTERLACED_TB)
 [V4L2_FIELD_INTERLACED_BT] = XLAT(V4L2_FIELD_INTERLACED_BT),
 #define XLAT_VAL_9 ((unsigned) (V4L2_FIELD_INTERLACED_BT))
 #define XLAT_STR_9 STRINGIFY(V4L2_FIELD_INTERLACED_BT)
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat v4l2_fields[1] = { {
 .data = v4l2_fields_xdata,
 .size = ARRAY_SIZE(v4l2_fields_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
