/* Generated by ./src/xlat/gen.sh from ./src/xlat/sigsys_codes.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(SYS_SECCOMP) || (defined(HAVE_DECL_SYS_SECCOMP) && HAVE_DECL_SYS_SECCOMP)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_SECCOMP) == (1), "SYS_SECCOMP != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_SECCOMP 1
#endif
#if defined(SYS_USER_DISPATCH) || (defined(HAVE_DECL_SYS_USER_DISPATCH) && HAVE_DECL_SYS_USER_DISPATCH)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SYS_USER_DISPATCH) == (2), "SYS_USER_DISPATCH != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SYS_USER_DISPATCH 2
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

extern const struct xlat sigsys_codes[];

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data sigsys_codes_xdata[] = {
 XLAT(SYS_SECCOMP),
 #define XLAT_VAL_0 ((unsigned) (SYS_SECCOMP))
 #define XLAT_STR_0 STRINGIFY(SYS_SECCOMP)
 XLAT(SYS_USER_DISPATCH),
 #define XLAT_VAL_1 ((unsigned) (SYS_USER_DISPATCH))
 #define XLAT_STR_1 STRINGIFY(SYS_USER_DISPATCH)
};
#  if !(defined HAVE_M32_MPERS || defined HAVE_MX32_MPERS)
static
#  endif
const struct xlat sigsys_codes[1] = { {
 .data = sigsys_codes_xdata,
 .size = ARRAY_SIZE(sigsys_codes_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
